@@ -14,7 +14,9 @@ FROM
     generate_series(1, 1000);
 
 INSERT INTO quad_point_tbl
-    VALUES (NULL), (NULL), (NULL);
+    VALUES (NULL),
+    (NULL),
+    (NULL);
 
 CREATE INDEX sp_quad_ind ON quad_point_tbl USING spgist (p);
 
