@@ -145,12 +145,13 @@ DROP VIEW viewtest;
 DROP TABLE viewtest_tbl;
 
 -- tests for temporary views
-CREATE SCHEMA temp_view_test CREATE TABLE base_table (
-    a int,
-    id int)
-CREATE TABLE base_table2 (
-    a int,
-    id int
+CREATE SCHEMA temp_view_test
+    CREATE TABLE base_table (
+        a int,
+        id int)
+    CREATE TABLE base_table2 (
+        a int,
+        id int
 );
 
 SET search_path TO temp_view_test, public;
@@ -196,9 +197,10 @@ FROM
     temp_table;
 
 -- should fail
-CREATE SCHEMA test_view_schema CREATE TEMP VIEW testview AS
-SELECT
-    1;
+CREATE SCHEMA test_view_schema
+    CREATE TEMP VIEW testview AS
+    SELECT
+        1;
 
 -- joins: if any of the join relations are temporary, the view
 -- should also be temporary
