@@ -108,28 +108,32 @@ SELECT
     SET ('t');
 
 INSERT INTO T
-    VALUES (1), (2);
+    VALUES (1),
+    (2);
 
 ALTER TABLE T
     ADD COLUMN c_bpchar BPCHAR(5) DEFAULT 'hello',
     ALTER COLUMN c_int SET DEFAULT 2;
 
 INSERT INTO T
-    VALUES (3), (4);
+    VALUES (3),
+    (4);
 
 ALTER TABLE T
     ADD COLUMN c_text TEXT DEFAULT 'world',
     ALTER COLUMN c_bpchar SET DEFAULT 'dog';
 
 INSERT INTO T
-    VALUES (5), (6);
+    VALUES (5),
+    (6);
 
 ALTER TABLE T
     ADD COLUMN c_date DATE DEFAULT '2016-06-02',
     ALTER COLUMN c_text SET DEFAULT 'cat';
 
 INSERT INTO T
-    VALUES (7), (8);
+    VALUES (7),
+    (8);
 
 ALTER TABLE T
     ADD COLUMN c_timestamp TIMESTAMP DEFAULT '2016-09-01 12:00:00',
@@ -137,7 +141,8 @@ ALTER TABLE T
     ALTER COLUMN c_date SET DEFAULT '2010-01-01';
 
 INSERT INTO T
-    VALUES (9), (10);
+    VALUES (9),
+    (10);
 
 ALTER TABLE T
     ADD COLUMN c_array TEXT[] DEFAULT '{"This", "is", "the", "real", "world"}',
@@ -145,7 +150,8 @@ ALTER TABLE T
     ALTER COLUMN c_timestamp_null SET DEFAULT '2016-09-29 12:00:00';
 
 INSERT INTO T
-    VALUES (11), (12);
+    VALUES (11),
+    (12);
 
 ALTER TABLE T
     ADD COLUMN c_small SMALLINT DEFAULT -5,
@@ -153,7 +159,8 @@ ALTER TABLE T
     ALTER COLUMN c_array SET DEFAULT '{"This", "is", "no", "fantasy"}';
 
 INSERT INTO T
-    VALUES (13), (14);
+    VALUES (13),
+    (14);
 
 ALTER TABLE T
     ADD COLUMN c_big BIGINT DEFAULT 180000000000018,
@@ -161,42 +168,48 @@ ALTER TABLE T
     ALTER COLUMN c_small_null SET DEFAULT 13;
 
 INSERT INTO T
-    VALUES (15), (16);
+    VALUES (15),
+    (16);
 
 ALTER TABLE T
     ADD COLUMN c_num NUMERIC DEFAULT 1.00000000001,
     ALTER COLUMN c_big SET DEFAULT -9999999999999999;
 
 INSERT INTO T
-    VALUES (17), (18);
+    VALUES (17),
+    (18);
 
 ALTER TABLE T
     ADD COLUMN c_time TIME DEFAULT '12:00:00',
     ALTER COLUMN c_num SET DEFAULT 2.000000000000002;
 
 INSERT INTO T
-    VALUES (19), (20);
+    VALUES (19),
+    (20);
 
 ALTER TABLE T
     ADD COLUMN c_interval INTERVAL DEFAULT '1 day',
     ALTER COLUMN c_time SET DEFAULT '23:59:59';
 
 INSERT INTO T
-    VALUES (21), (22);
+    VALUES (21),
+    (22);
 
 ALTER TABLE T
     ADD COLUMN c_hugetext TEXT DEFAULT repeat('abcdefg', 1000),
     ALTER COLUMN c_interval SET DEFAULT '3 hours';
 
 INSERT INTO T
-    VALUES (23), (24);
+    VALUES (23),
+    (24);
 
 ALTER TABLE T
     ALTER COLUMN c_interval DROP DEFAULT,
     ALTER COLUMN c_hugetext SET DEFAULT repeat('poiuyt', 1000);
 
 INSERT INTO T
-    VALUES (25), (26);
+    VALUES (25),
+    (26);
 
 ALTER TABLE T
     ALTER COLUMN c_bpchar DROP DEFAULT,
@@ -211,7 +224,8 @@ ALTER TABLE T
     ALTER COLUMN c_hugetext DROP DEFAULT;
 
 INSERT INTO T
-    VALUES (27), (28);
+    VALUES (27),
+    (28);
 
 SELECT
     pk,
@@ -269,49 +283,56 @@ SELECT
     SET ('t');
 
 INSERT INTO T
-    VALUES (1), (2);
+    VALUES (1),
+    (2);
 
 ALTER TABLE T
     ADD COLUMN c_bpchar BPCHAR(5) DEFAULT foo (4),
     ALTER COLUMN c_int SET DEFAULT LENGTH(foo (8));
 
 INSERT INTO T
-    VALUES (3), (4);
+    VALUES (3),
+    (4);
 
 ALTER TABLE T
     ADD COLUMN c_text TEXT DEFAULT foo (6),
     ALTER COLUMN c_bpchar SET DEFAULT foo (3);
 
 INSERT INTO T
-    VALUES (5), (6);
+    VALUES (5),
+    (6);
 
 ALTER TABLE T
     ADD COLUMN c_date DATE DEFAULT '2016-06-02'::date + LENGTH(foo (10)),
     ALTER COLUMN c_text SET DEFAULT foo (12);
 
 INSERT INTO T
-    VALUES (7), (8);
+    VALUES (7),
+    (8);
 
 ALTER TABLE T
     ADD COLUMN c_timestamp TIMESTAMP DEFAULT '2016-09-01'::date + LENGTH(foo (10)),
     ALTER COLUMN c_date SET DEFAULT '2010-01-01'::date - LENGTH(foo (4));
 
 INSERT INTO T
-    VALUES (9), (10);
+    VALUES (9),
+    (10);
 
 ALTER TABLE T
     ADD COLUMN c_array TEXT[] DEFAULT ('{"This", "is", "' || foo (4) || '","the", "real", "world"}')::text[],
     ALTER COLUMN c_timestamp SET DEFAULT '1970-12-31'::date + LENGTH(foo (30));
 
 INSERT INTO T
-    VALUES (11), (12);
+    VALUES (11),
+    (12);
 
 ALTER TABLE T
     ALTER COLUMN c_int DROP DEFAULT,
     ALTER COLUMN c_array SET DEFAULT ('{"This", "is", "' || foo (1) || '", "fantasy"}')::text[];
 
 INSERT INTO T
-    VALUES (13), (14);
+    VALUES (13),
+    (14);
 
 ALTER TABLE T
     ALTER COLUMN c_bpchar DROP DEFAULT,
@@ -321,7 +342,8 @@ ALTER TABLE T
     ALTER COLUMN c_array DROP DEFAULT;
 
 INSERT INTO T
-    VALUES (15), (16);
+    VALUES (15),
+    (16);
 
 SELECT
     *
@@ -558,26 +580,30 @@ SELECT
     SET ('t');
 
 INSERT INTO T
-    VALUES (1), (2);
+    VALUES (1),
+    (2);
 
 ALTER TABLE T
     ADD COLUMN c_int INT NOT NULL DEFAULT -1;
 
 INSERT INTO T
-    VALUES (3), (4);
+    VALUES (3),
+    (4);
 
 ALTER TABLE T
     ADD COLUMN c_text TEXT DEFAULT 'Hello';
 
 INSERT INTO T
-    VALUES (5), (6);
+    VALUES (5),
+    (6);
 
 ALTER TABLE T
     ALTER COLUMN c_text SET DEFAULT 'world',
     ALTER COLUMN c_int SET DEFAULT 1;
 
 INSERT INTO T
-    VALUES (7), (8);
+    VALUES (7),
+    (8);
 
 SELECT
     *
@@ -963,7 +989,8 @@ CREATE TABLE follower (
 );
 
 INSERT INTO leader
-    VALUES (1, 1), (2, 2);
+    VALUES (1, 1),
+    (2, 2);
 
 ALTER TABLE leader
     ADD c int;
