@@ -1909,7 +1909,8 @@ CREATE temp TABLE selfref (
 );
 
 INSERT INTO selfref (a, b)
-    VALUES (0, 0), (1, 1);
+    VALUES (0, 0),
+    (1, 1);
 
 BEGIN;
 UPDATE
@@ -1948,7 +1949,9 @@ CREATE temp TABLE defc (
 );
 
 INSERT INTO defp
-    VALUES (0), (1), (2);
+    VALUES (0),
+    (1),
+    (2);
 
 INSERT INTO defc
     VALUES (2);
@@ -2373,7 +2376,10 @@ INSERT INTO fk_partitioned_fk_3 (a, b)
 
 -- but if we insert the values that make them valid, then they work
 INSERT INTO fk_notpartitioned_pk
-    VALUES (500, 501), (1500, 1501), (2500, 2502), (2501, 2503);
+    VALUES (500, 501),
+    (1500, 1501),
+    (2500, 2502),
+    (2501, 2503);
 
 INSERT INTO fk_partitioned_fk (a, b)
     VALUES (500, 501);
@@ -2801,13 +2807,15 @@ CREATE TABLE fk_partitioned_fk_2_2 PARTITION OF fk_partitioned_fk_2
 FOR VALUES FROM (1000) TO (2000);
 
 INSERT INTO fk_partitioned_fk_2
-    VALUES (1600, 601), (1600, 1601);
+    VALUES (1600, 601),
+    (1600, 1601);
 
 ALTER TABLE fk_partitioned_fk ATTACH PARTITION fk_partitioned_fk_2
 FOR VALUES IN (1600);
 
 INSERT INTO fk_notpartitioned_pk
-    VALUES (1600, 601), (1600, 1601);
+    VALUES (1600, 601),
+    (1600, 1601);
 
 ALTER TABLE fk_partitioned_fk ATTACH PARTITION fk_partitioned_fk_2
 FOR VALUES IN (1600);
@@ -2867,15 +2875,19 @@ DROP ROLE regress_other_partitioned_fk_owner;
 -- Test creating a constraint at the parent that already exists in partitions.
 -- There should be no duplicated constraints, and attempts to drop the
 -- constraint in partitions should raise appropriate errors.
-CREATE SCHEMA fkpart0 CREATE TABLE pkey (
-    a int PRIMARY KEY)
-CREATE TABLE fk_part (
-    a int
+CREATE SCHEMA fkpart0
+    CREATE TABLE pkey (
+        a int PRIMARY KEY)
+    CREATE TABLE fk_part (
+        a int
 )
-PARTITION BY LIST (a) CREATE TABLE fk_part_1 PARTITION OF fk_part (FOREIGN KEY (a) REFERENCES fkpart0.pkey)
-FOR VALUES IN (1) CREATE TABLE fk_part_23 PARTITION OF fk_part (FOREIGN KEY (a) REFERENCES fkpart0.pkey)
+PARTITION BY LIST (a)
+    CREATE TABLE fk_part_1 PARTITION OF fk_part (FOREIGN KEY (a) REFERENCES fkpart0.pkey)
+FOR VALUES IN (1)
+    CREATE TABLE fk_part_23 PARTITION OF fk_part (FOREIGN KEY (a) REFERENCES fkpart0.pkey)
 FOR VALUES IN (2, 3)
-PARTITION BY LIST (a) CREATE TABLE fk_part_23_2 PARTITION OF fk_part_23
+PARTITION BY LIST (a)
+    CREATE TABLE fk_part_23_2 PARTITION OF fk_part_23
 FOR VALUES IN (2);
 
 ALTER TABLE fkpart0.fk_part
@@ -2916,14 +2928,17 @@ ALTER TABLE fkpart0.fk_part_56_5
 
 -- verify that attaching and detaching partitions maintains the right set of
 -- triggers
-CREATE SCHEMA fkpart1 CREATE TABLE pkey (
-    a int PRIMARY KEY)
-CREATE TABLE fk_part (
-    a int
+CREATE SCHEMA fkpart1
+    CREATE TABLE pkey (
+        a int PRIMARY KEY)
+    CREATE TABLE fk_part (
+        a int
 )
-PARTITION BY LIST (a) CREATE TABLE fk_part_1 PARTITION OF fk_part
+PARTITION BY LIST (a)
+    CREATE TABLE fk_part_1 PARTITION OF fk_part
 FOR VALUES IN (1)
-PARTITION BY LIST (a) CREATE TABLE fk_part_1_1 PARTITION OF fk_part_1
+PARTITION BY LIST (a)
+    CREATE TABLE fk_part_1_1 PARTITION OF fk_part_1
 FOR VALUES IN (1);
 
 ALTER TABLE fkpart1.fk_part
@@ -2957,15 +2972,18 @@ WHERE a = 1;
 
 -- verify that attaching and detaching partitions manipulates the inheritance
 -- properties of their FK constraints correctly
-CREATE SCHEMA fkpart2 CREATE TABLE pkey (
-    a int PRIMARY KEY)
-CREATE TABLE fk_part (
-    a int,
-    CONSTRAINT fkey FOREIGN KEY (a) REFERENCES fkpart2.pkey
+CREATE SCHEMA fkpart2
+    CREATE TABLE pkey (
+        a int PRIMARY KEY)
+    CREATE TABLE fk_part (
+        a int,
+        CONSTRAINT fkey FOREIGN KEY (a) REFERENCES fkpart2.pkey
 )
-PARTITION BY LIST (a) CREATE TABLE fk_part_1 PARTITION OF fkpart2.fk_part
+PARTITION BY LIST (a)
+    CREATE TABLE fk_part_1 PARTITION OF fkpart2.fk_part
 FOR VALUES IN (1)
-PARTITION BY LIST (a) CREATE TABLE fk_part_1_1 (a int, CONSTRAINT my_fkey FOREIGN KEY (a) REFERENCES fkpart2.pkey);
+PARTITION BY LIST (a)
+    CREATE TABLE fk_part_1_1 (a int, CONSTRAINT my_fkey FOREIGN KEY (a) REFERENCES fkpart2.pkey);
 
 ALTER TABLE fkpart2.fk_part_1 ATTACH PARTITION fkpart2.fk_part_1_1
 FOR VALUES IN (1);
@@ -3096,10 +3114,20 @@ INSERT INTO fk
 
 -- insert into the referenced table, now they should work
 INSERT INTO pk
-    VALUES (1), (1000), (2000), (3000), (4000), (4500);
+    VALUES (1),
+    (1000),
+    (2000),
+    (3000),
+    (4000),
+    (4500);
 
 INSERT INTO fk
-    VALUES (1), (1000), (2000), (3000), (4000), (4500);
+    VALUES (1),
+    (1000),
+    (2000),
+    (3000),
+    (4000),
+    (4500);
 
 -- should fail: referencing value present
 DELETE FROM pk
@@ -3251,14 +3279,20 @@ FOR VALUES FROM (1000) TO (1400);
 CREATE TABLE droppk2_d PARTITION OF droppk2 DEFAULT;
 
 INSERT INTO droppk
-    VALUES (1), (1000), (1500), (2000);
+    VALUES (1),
+    (1000),
+    (1500),
+    (2000);
 
 CREATE TABLE dropfk (
     a int REFERENCES droppk
 );
 
 INSERT INTO dropfk
-    VALUES (1), (1000), (1500), (2000);
+    VALUES (1),
+    (1000),
+    (1500),
+    (2000);
 
 -- these should all fail
 ALTER TABLE droppk DETACH PARTITION droppk_d;
@@ -3468,7 +3502,8 @@ DROP TABLE fk;
 TRUNCATE TABLE pk;
 
 INSERT INTO pk
-    VALUES (20), (50);
+    VALUES (20),
+    (50);
 
 CREATE TABLE fk (
     a int
@@ -3491,7 +3526,8 @@ ALTER TABLE fk
 CREATE TABLE fk_d PARTITION OF fk DEFAULT;
 
 INSERT INTO fk
-    VALUES (20), (50);
+    VALUES (20),
+    (50);
 
 UPDATE
     pk
@@ -3514,7 +3550,9 @@ DROP TABLE fk;
 TRUNCATE TABLE pk;
 
 INSERT INTO pk
-    VALUES (20), (30), (50);
+    VALUES (20),
+    (30),
+    (50);
 
 CREATE TABLE fk (
     id int,
@@ -3538,7 +3576,8 @@ ALTER TABLE fk
 CREATE TABLE fk_d PARTITION OF fk DEFAULT;
 
 INSERT INTO fk
-    VALUES (1, 20), (2, 30);
+    VALUES (1, 20),
+    (2, 30);
 
 DELETE FROM pk
 WHERE a = 20
@@ -3565,7 +3604,8 @@ DROP TABLE fk;
 TRUNCATE TABLE pk;
 
 INSERT INTO pk
-    VALUES (20), (30);
+    VALUES (20),
+    (30);
 
 CREATE TABLE fk (
     a int DEFAULT 50
@@ -3588,7 +3628,8 @@ ALTER TABLE fk
 CREATE TABLE fk_d PARTITION OF fk DEFAULT;
 
 INSERT INTO fk
-    VALUES (20), (30);
+    VALUES (20),
+    (30);
 
 DELETE FROM pk
 WHERE a = 20;
@@ -3610,10 +3651,12 @@ DROP TABLE fk;
 
 -- test for reported bug: relispartition not set
 -- https://postgr.es/m/CA+HiwqHMsRtRYRWYTWavKJ8x14AFsv7bmAV46mYwnfD3vy8goQ@mail.gmail.com
-CREATE SCHEMA fkpart7 CREATE TABLE pkpart (
-    a int
+CREATE SCHEMA fkpart7
+    CREATE TABLE pkpart (
+        a int
 )
-PARTITION BY LIST (a) CREATE TABLE pkpart1 PARTITION OF pkpart
+PARTITION BY LIST (a)
+    CREATE TABLE pkpart1 PARTITION OF pkpart
 FOR VALUES IN (1);
 
 ALTER TABLE fkpart7.pkpart1
