@@ -278,7 +278,9 @@ CREATE TEMP TABLE test_jsonb (
 );
 
 INSERT INTO test_jsonb
-    VALUES ('scalar', '"a scalar"'), ('array', '["zero", "one","two",null,"four","five", [1,2,3],{"f1":9}]'), ('object', '{"field1":"val1","field2":"val2","field3":null, "field4": 4, "field5": [1,2,3], "field6": {"f1":9}}');
+    VALUES ('scalar', '"a scalar"'),
+    ('array', '["zero", "one","two",null,"four","five", [1,2,3],{"f1":9}]'),
+    ('object', '{"field1":"val1","field2":"val2","field3":null, "field4": 4, "field5": [1,2,3], "field6": {"f1":9}}');
 
 SELECT
     test_json -> 'x'
@@ -783,19 +785,19 @@ SELECT
     jsonb_exists_any ('{"a":null, "b":"qq"}', '{}'::text[]);
 
 SELECT
-    jsonb '{"a":null, "b":"qq"}' ? | ARRAY['a', 'b'];
+    jsonb '{"a":null, "b":"qq"}' ?| ARRAY['a', 'b'];
 
 SELECT
-    jsonb '{"a":null, "b":"qq"}' ? | ARRAY['b', 'a'];
+    jsonb '{"a":null, "b":"qq"}' ?| ARRAY['b', 'a'];
 
 SELECT
-    jsonb '{"a":null, "b":"qq"}' ? | ARRAY['c', 'a'];
+    jsonb '{"a":null, "b":"qq"}' ?| ARRAY['c', 'a'];
 
 SELECT
-    jsonb '{"a":null, "b":"qq"}' ? | ARRAY['c', 'd'];
+    jsonb '{"a":null, "b":"qq"}' ?| ARRAY['c', 'd'];
 
 SELECT
-    jsonb '{"a":null, "b":"qq"}' ? | '{}'::text[];
+    jsonb '{"a":null, "b":"qq"}' ?| '{}'::text[];
 
 SELECT
     jsonb_exists_all ('{"a":null, "b":"qq"}', ARRAY['a', 'b']);
@@ -2040,7 +2042,7 @@ SELECT
 FROM
     testjsonb
 WHERE
-    j ? | ARRAY['public', 'disabled'];
+    j ?| ARRAY['public', 'disabled'];
 
 SELECT
     count(*)
@@ -2255,7 +2257,7 @@ SELECT
 FROM
     testjsonb
 WHERE
-    j ? | ARRAY['public', 'disabled'];
+    j ?| ARRAY['public', 'disabled'];
 
 SELECT
     count(*)
