@@ -85,8 +85,12 @@ SELECT
 
 SELECT
     '"\b\f\r\n\t\v\"\'' \\ "'::jsonpath;
-select '''\b\f\r\n\t\v\"\''\\'''::jsonpath;
-select '" x50 u0067 u {53} u {051} u {00004C}"'::jsonpath;
+
+SELECT
+    '''\b\f\r\n\t\v\"\''\\'' '::jsonpath;
+
+SELECT
+    '"\x50\u0067\u{53}\u{051}\u{00004C}"'::jsonpath;
 
 SELECT
     '''\x50\u0067\u{53}\u{051}\u{00004C}'''::jsonpath;
