@@ -114,9 +114,7 @@ CREATE TRANSFORM FOR int
 LANGUAGE SQL
 (
 FROM
-    SQL WITH FUNCTION prsd_lextype( internal
-),
-TO SQL WITH FUNCTION int4recv( internal));
+    SQL WITH FUNCTION prsd_lextype(internal), TO SQL WITH FUNCTION int4recv(internal));
 
 CREATE PUBLICATION addr_pub FOR TABLE addr_nsp.gentable;
 
@@ -147,10 +145,10 @@ BEGIN
         BEGIN
             PERFORM
                 pg_get_object_address(objtype, '{one}', '{}');
-            EXCEPTION
+        EXCEPTION
             WHEN invalid_parameter_value THEN
                 RAISE WARNING 'error for %: %', objtype, sqlerrm;
-            END;
+        END;
     END LOOP;
 END;
 
@@ -192,10 +190,10 @@ BEGIN
                 BEGIN
                     PERFORM
                         pg_get_object_address(objtype, names, args);
-                    EXCEPTION
+                EXCEPTION
                     WHEN OTHERS THEN
                         RAISE WARNING 'error for %,%,%: %', objtype, names, args, sqlerrm;
-                    END;
+                END;
             END LOOP;
         END LOOP;
     END LOOP;
@@ -287,7 +285,7 @@ SELECT
 
 -- test successful cases
 WITH objects (
-    TYPE,
+    type,
     name,
     args
 ) AS (
@@ -352,7 +350,7 @@ SELECT
     ROW (pg_identify_object (addr1.classid, addr1.objid, addr1.objsubid)) = ROW (pg_identify_object (addr2.classid, addr2.objid, addr2.objsubid))
 FROM
     objects,
-    pg_get_object_address(TYPE, name, args) addr1,
+    pg_get_object_address(type, name, args) addr1,
     pg_identify_object_as_address(classid, objid, objsubid) ioa (typ, nms, args),
     pg_get_object_address(typ, nms, ioa.args) AS addr2
 ORDER BY
