@@ -76,7 +76,9 @@ FROM
     generate_series(10001, 11000) AS i;
 
 INSERT INTO quad_poly_tbl
-    VALUES (11001, NULL), (11002, NULL), (11003, NULL);
+    VALUES (11001, NULL),
+    (11002, NULL),
+    (11003, NULL);
 
 CREATE INDEX quad_poly_tbl_idx ON quad_poly_tbl USING spgist (p);
 
