@@ -198,7 +198,8 @@ WHERE
     oid = 'reloptions_test'::regclass;
 
 INSERT INTO reloptions_test
-    VALUES (1, NULL), (NULL, NULL);
+    VALUES (1, NULL),
+    (NULL, NULL);
 
 VACUUM reloptions_test;
 
@@ -228,7 +229,8 @@ WHERE
     oid = 'reloptions_test'::regclass;
 
 INSERT INTO reloptions_test
-    VALUES (1, NULL), (NULL, NULL);
+    VALUES (1, NULL),
+    (NULL, NULL);
 
 VACUUM reloptions_test;
 
