@@ -179,7 +179,8 @@ INSERT INTO serialTest2 (f1)
     VALUES ('test_defaults');
 
 INSERT INTO serialTest2 (f1, f2, f3, f4, f5, f6)
-    VALUES ('test_max_vals', 2147483647, 32767, 32767, 9223372036854775807, 9223372036854775807), ('test_min_vals', -2147483648, -32768, -32768, -9223372036854775808, -9223372036854775808);
+    VALUES ('test_max_vals', 2147483647, 32767, 32767, 9223372036854775807, 9223372036854775807),
+    ('test_min_vals', -2147483648, -32768, -32768, -9223372036854775808, -9223372036854775808);
 
 -- All these INSERTs should fail:
 INSERT INTO serialTest2 (f1, f3)
