@@ -31,9 +31,9 @@ FROM (
 
 SELECT
     *
-FROM ((
+FROM (
         SELECT
-            1 AS x)) ss;
+            1 AS x) ss;
 
 (
     SELECT
@@ -58,9 +58,9 @@ SELECT
             2);
 
 SELECT
-    (((
+    ((
                 SELECT
-                    2))
+                    2)
         UNION
         SELECT
             2);
@@ -71,14 +71,14 @@ SELECT
             ARRAY[1, 2, 3])[1];
 
 SELECT
-    ((
+    (
             SELECT
-                ARRAY[1, 2, 3]))[2];
+                ARRAY[1, 2, 3])[2];
 
 SELECT
-    (((
+    (
                 SELECT
-                    ARRAY[1, 2, 3])))[3];
+                    ARRAY[1, 2, 3])[3];
 
 -- Set up some simple test tables
 CREATE TABLE SUBSELECT_TBL (
@@ -800,14 +800,19 @@ CREATE temp TABLE numeric_table (
 );
 
 INSERT INTO numeric_table
-    VALUES (1), (1.000000000000000000001), (2), (3);
+    VALUES (1),
+    (1.000000000000000000001),
+    (2),
+    (3);
 
 CREATE temp TABLE float_table (
     float_col float8
 );
 
 INSERT INTO float_table
-    VALUES (1), (2), (3);
+    VALUES (1),
+    (2),
+    (3);
 
 SELECT
     *
@@ -1078,7 +1083,8 @@ WITH aa AS (
         int4_tbl
     LIMIT 1)
     INSERT INTO upsert
-        VALUES (1, 'x'), (999, 'y')
+        VALUES (1, 'x'),
+        (999, 'y')
     ON CONFLICT (key)
         DO UPDATE SET
             val = (
@@ -1288,7 +1294,8 @@ CREATE temp TABLE notininner (
 );
 
 INSERT INTO notinouter
-    VALUES (NULL), (1);
+    VALUES (NULL),
+    (1);
 
 SELECT
     *
@@ -1321,9 +1328,9 @@ SELECT
 FROM
     generate_series(1, 10) AS s (i),
     LATERAL (
-        VALUES ((
+        VALUES (
                     SELECT
-                        s.i + 1)),
+                        s.i + 1),
                 (s.i + 101)) AS val (x)
 WHERE
     s.i < 10
@@ -1552,7 +1559,14 @@ CREATE TABLE sq_limit (
 );
 
 INSERT INTO sq_limit
-    VALUES (1, 1, 1), (2, 2, 2), (3, 3, 3), (4, 4, 4), (5, 1, 1), (6, 2, 2), (7, 3, 3), (8, 4, 4);
+    VALUES (1, 1, 1),
+    (2, 2, 2),
+    (3, 3, 3),
+    (4, 4, 4),
+    (5, 1, 1),
+    (6, 2, 2),
+    (7, 3, 3),
+    (8, 4, 4);
 
 CREATE FUNCTION explain_sq_limit ()
     RETURNS SETOF text
