@@ -49,7 +49,9 @@ CREATE TABLE few (
 );
 
 INSERT INTO few
-    VALUES (1, 'a', 'foo'), (2, 'a', 'bar'), (3, 'b', 'bar');
+    VALUES (1, 'a', 'foo'),
+    (2, 'a', 'bar'),
+    (3, 'b', 'bar');
 
 -- SRF with a provably-dummy relation
 EXPLAIN (
