@@ -1785,7 +1785,9 @@ CREATE TABLE base_tbl (
 );
 
 INSERT INTO base_tbl
-    VALUES (1, 2), (4, 5), (3, -3);
+    VALUES (1, 2),
+    (4, 5),
+    (3, -3);
 
 CREATE VIEW rw_view1 AS
 SELECT
@@ -1839,7 +1841,8 @@ CREATE TABLE base_tbl (
 );
 
 INSERT INTO base_tbl
-    VALUES (1, ARRAY[2]), (3, ARRAY[4]);
+    VALUES (1, ARRAY[2]),
+    (3, ARRAY[4]);
 
 CREATE VIEW rw_view1 AS
 SELECT
@@ -2113,10 +2116,12 @@ ORDER BY
     a;
 
 INSERT INTO rw_view1
-    VALUES (-100), (100);
+    VALUES (-100),
+    (100);
 
 INSERT INTO rw_view2
-    VALUES (-200), (200);
+    VALUES (-200),
+    (200);
 
 UPDATE
     rw_view1
@@ -2190,10 +2195,12 @@ INHERITS (
 );
 
 INSERT INTO other_tbl_parent
-    VALUES (7), (200);
+    VALUES (7),
+    (200);
 
 INSERT INTO other_tbl_child
-    VALUES (8), (100);
+    VALUES (8),
+    (100);
 
 EXPLAIN (
     COSTS OFF
@@ -2240,7 +2247,9 @@ CREATE TABLE base_tbl (
 );
 
 INSERT INTO base_tbl
-    VALUES (1, 2), (2, 3), (1, -1);
+    VALUES (1, 2),
+    (2, 3),
+    (1, -1);
 
 CREATE VIEW rw_view1 AS
 SELECT
@@ -2837,7 +2846,9 @@ CREATE TABLE base_tbl (
 );
 
 INSERT INTO base_tbl
-    VALUES ('Tom', 'public'), ('Dick', 'private'), ('Harry', 'public');
+    VALUES ('Tom', 'public'),
+    ('Dick', 'private'),
+    ('Harry', 'public');
 
 CREATE VIEW rw_view1 AS
 SELECT
@@ -3046,7 +3057,8 @@ CREATE TABLE base_tbl (
 );
 
 INSERT INTO base_tbl
-    VALUES (1, 'Row 1', FALSE), (2, 'Row 2', TRUE);
+    VALUES (1, 'Row 1', FALSE),
+    (2, 'Row 2', TRUE);
 
 CREATE RULE base_tbl_ins_rule AS ON INSERT TO base_tbl WHERE
     EXISTS (
@@ -3482,7 +3494,8 @@ CREATE TABLE t2 (
 );
 
 INSERT INTO t2
-    VALUES (10), (20);
+    VALUES (10),
+    (20);
 
 CREATE VIEW v1 WITH ( security_barrier = TRUE
 ) AS
@@ -3738,7 +3751,8 @@ CREATE TABLE sometable (
 );
 
 INSERT INTO sometable
-    VALUES (1, 'a'), (2, 'b');
+    VALUES (1, 'a'),
+    (2, 'b');
 
 CREATE VIEW wcowrtest_v2 AS
 SELECT
@@ -4146,28 +4160,33 @@ INSERT INTO base_tab_def
     VALUES (1);
 
 INSERT INTO base_tab_def
-    VALUES (2), (3);
+    VALUES (2),
+    (3);
 
 INSERT INTO base_tab_def
     VALUES (4, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
 
 INSERT INTO base_tab_def
-    VALUES (5, DEFAULT, DEFAULT, DEFAULT, DEFAULT), (6, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
+    VALUES (5, DEFAULT, DEFAULT, DEFAULT, DEFAULT),
+    (6, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
 
 INSERT INTO base_tab_def_view
     VALUES (11);
 
 INSERT INTO base_tab_def_view
-    VALUES (12), (13);
+    VALUES (12),
+    (13);
 
 INSERT INTO base_tab_def_view
     VALUES (14, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
 
 INSERT INTO base_tab_def_view
-    VALUES (15, DEFAULT, DEFAULT, DEFAULT, DEFAULT), (16, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
+    VALUES (15, DEFAULT, DEFAULT, DEFAULT, DEFAULT),
+    (16, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
 
 INSERT INTO base_tab_def_view
-    VALUES (17), (DEFAULT);
+    VALUES (17),
+    (DEFAULT);
 
 SELECT
     *
@@ -4199,28 +4218,33 @@ INSERT INTO base_tab_def
     VALUES (1);
 
 INSERT INTO base_tab_def
-    VALUES (2), (3);
+    VALUES (2),
+    (3);
 
 INSERT INTO base_tab_def
     VALUES (4, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
 
 INSERT INTO base_tab_def
-    VALUES (5, DEFAULT, DEFAULT, DEFAULT, DEFAULT), (6, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
+    VALUES (5, DEFAULT, DEFAULT, DEFAULT, DEFAULT),
+    (6, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
 
 INSERT INTO base_tab_def_view
     VALUES (11);
 
 INSERT INTO base_tab_def_view
-    VALUES (12), (13);
+    VALUES (12),
+    (13);
 
 INSERT INTO base_tab_def_view
     VALUES (14, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
 
 INSERT INTO base_tab_def_view
-    VALUES (15, DEFAULT, DEFAULT, DEFAULT, DEFAULT), (16, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
+    VALUES (15, DEFAULT, DEFAULT, DEFAULT, DEFAULT),
+    (16, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
 
 INSERT INTO base_tab_def_view
-    VALUES (17), (DEFAULT);
+    VALUES (17),
+    (DEFAULT);
 
 SELECT
     *
@@ -4245,28 +4269,33 @@ INSERT INTO base_tab_def
     VALUES (1);
 
 INSERT INTO base_tab_def
-    VALUES (2), (3);
+    VALUES (2),
+    (3);
 
 INSERT INTO base_tab_def
     VALUES (4, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
 
 INSERT INTO base_tab_def
-    VALUES (5, DEFAULT, DEFAULT, DEFAULT, DEFAULT), (6, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
+    VALUES (5, DEFAULT, DEFAULT, DEFAULT, DEFAULT),
+    (6, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
 
 INSERT INTO base_tab_def_view
     VALUES (11);
 
 INSERT INTO base_tab_def_view
-    VALUES (12), (13);
+    VALUES (12),
+    (13);
 
 INSERT INTO base_tab_def_view
     VALUES (14, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
 
 INSERT INTO base_tab_def_view
-    VALUES (15, DEFAULT, DEFAULT, DEFAULT, DEFAULT), (16, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
+    VALUES (15, DEFAULT, DEFAULT, DEFAULT, DEFAULT),
+    (16, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
 
 INSERT INTO base_tab_def_view
-    VALUES (17), (DEFAULT);
+    VALUES (17),
+    (DEFAULT);
 
 SELECT
     *
@@ -4292,28 +4321,33 @@ INSERT INTO base_tab_def
     VALUES (1);
 
 INSERT INTO base_tab_def
-    VALUES (2), (3);
+    VALUES (2),
+    (3);
 
 INSERT INTO base_tab_def
     VALUES (4, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
 
 INSERT INTO base_tab_def
-    VALUES (5, DEFAULT, DEFAULT, DEFAULT, DEFAULT), (6, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
+    VALUES (5, DEFAULT, DEFAULT, DEFAULT, DEFAULT),
+    (6, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
 
 INSERT INTO base_tab_def_view
     VALUES (11);
 
 INSERT INTO base_tab_def_view
-    VALUES (12), (13);
+    VALUES (12),
+    (13);
 
 INSERT INTO base_tab_def_view
     VALUES (14, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
 
 INSERT INTO base_tab_def_view
-    VALUES (15, DEFAULT, DEFAULT, DEFAULT, DEFAULT), (16, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
+    VALUES (15, DEFAULT, DEFAULT, DEFAULT, DEFAULT),
+    (16, DEFAULT, DEFAULT, DEFAULT, DEFAULT);
 
 INSERT INTO base_tab_def_view
-    VALUES (17), (DEFAULT);
+    VALUES (17),
+    (DEFAULT);
 
 SELECT
     *
@@ -4347,7 +4381,8 @@ ALTER VIEW base_tab_view
     ALTER COLUMN c SET DEFAULT 'View default';
 
 INSERT INTO base_tab_view (b[1], b[2], c, b[5], b[4], a, b[3])
-    VALUES (1, 2, DEFAULT, 5, 4, DEFAULT, 3), (10, 11, 'C value', 14, 13, 100, 12);
+    VALUES (1, 2, DEFAULT, 5, 4, DEFAULT, 3),
+    (10, 11, 'C value', 14, 13, 100, 12);
 
 SELECT
     *
