@@ -203,14 +203,19 @@ CLUSTER vaccluster;
 CREATE FUNCTION do_analyze ()
     RETURNS VOID VOLATILE
     LANGUAGE SQL
-    AS 'ANALYZE pg_am'
-;
+    AS '
+    ANALYZE pg_am;
+';
 
 CREATE FUNCTION wrap_do_analyze (c int)
     RETURNS int IMMUTABLE
     LANGUAGE SQL
-    AS 'SELECT $1 FROM do_analyze()'
-;
+    AS '
+    SELECT
+        $1
+    FROM
+        do_analyze ();
+';
 
 CREATE INDEX ON vaccluster (wrap_do_analyze (i));
 
